@@ -1,8 +1,8 @@
-use dochy_core::structs::{MutInnerList, ListDefObj, MetaTables};
+use dochy_core::structs::{MutListVal, ListDefObj, MetaTables};
 use crate::imp::structs_write::{ListDiffW, ListItemDiffEnumW, BS};
 use crate::imp::prepare::new_item::new_item;
 
-pub(crate) fn new_list<'a, 'b>(mil : &'a MutInnerList, def : &'a ListDefObj, meta : &'a MetaTables) -> ListDiffW<'a>{
+pub(crate) fn new_list<'a, 'b>(mil : &'a MutListVal, def : &'a ListDefObj, meta : &'a MetaTables) -> ListDiffW<'a>{
     let mut result : Vec<(u64, ListItemDiffEnumW)> = Vec::new();
 
     let mut prev_id : Option<u64> = None;
